==> typo3-6.0.4.tbz: www/typo3_src-6.0.4/typo3/sysext/core/Tests/Unit/Utility/Fixtures/MathUtilityTestClassWithStringRepresentationFixture.php <==
<?php
namespace TYPO3\CMS\Core\Tests\Unit\Utility\Fixtures;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Philipp Gampe (forge.typo3.org@philippgampe.info)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Class t3lib_utility_math_fixture_classWithStringRepresentation.
 *
 * This is a fixture subclass for t3lib_utility_math
 *
 */
class MathUtilityTestClassWithStringRepresentationFixture {

	protected $string = '';

	public function __toString() {
		return $this->getString();
	}

	public function setString($string) {
		$this->string = $string;
	}

	public function getString() {
		return $this->string;
	}

}

?>

==> typo3-6.1.0.tbz: www/typo3_src-6.1.0/typo3/sysext/core/Tests/Unit/Utility/Fixtures/MathUtilityTestClassWithStringRepresentationFixture.php <==
<?php
namespace TYPO3\CMS\Core\Tests\Unit\Utility\Fixtures;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012-2013 Philipp Gampe (forge.typo3.org@philippgampe.info)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *  A copy is found in the textfile GPL.txt and important notices to the license
 *  from the author is found in LICENSE.txt distributed with these scripts.
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * This is a fixture subclass for \TYPO3\CMS\Core\Utility\MathUtility
 */
class MathUtilityTestClassWithStringRepresentationFixture {

	protected $string = '';

	public function __toString() {
		return $this->getString();
	}

	public function setString($string) {
		$this->string = $string;
	}

	public function getString() {
		return $this->string;
	}

}

?>
